#!/bin/sh
echo 'name: logict
version: 0.5.0.1
id: logict-0.5.0.1-f5871108fc142912fe5ecea3a877dda7

license: BSD3
copyright: Copyright (c) 2007-2010, Dan Doel,
           Copyright (c) 2011, Edward Kmett
maintainer: dan.doel@gmail.com
stability: Experimental
homepage: http://code.haskell.org/~dolio/logict
package-url:
synopsis: A backtracking logic-programming monad.
description: A continuation-based, backtracking, logic programming monad.
             An adaptation of the two-continuation implementation found
             in the paper "Backtracking, Interleaving, and Terminating
             Monad Transformers" available here:
             <http://okmij.org/ftp/papers/LogicT.pdf>
category: Control
author: Dan Doel
pkgpath: devel/hs-logict
exposed: True
exposed-modules: Control.Monad.Logic Control.Monad.Logic.Class
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/logict-0.5.0.1
library-dirs: /usr/local/lib/ghc/logict-0.5.0.1
hs-libraries: HSlogict-0.5.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-logict-0.5.0.1/html/logict.haddock
haddock-html: /usr/local/share/doc/hs-logict-0.5.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
